
# Type: chemical formula value


A chemical formula

URI: [biolink:ChemicalFormulaValue](https://w3id.org/biolink/vocab/ChemicalFormulaValue)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **str** |
